@@ -608,6 +608,10 @@ class RabbitMQClient:
         if not self.message_handler or not self._is_consuming:
             logger.warning("未设置消息处理器或已停止消费")
             # await message.ack()
+            try:
+                await message.reject(requeue=True)
+            except Exception as e:
+                logger.error(f"拒绝消息失败: {e}")
             return
 
         message_id = message.message_id or str(id(message))
